@@ -1,5 +1,5 @@
 package Test::Requires::Git;
-$Test::Requires::Git::VERSION = '1.005';
+$Test::Requires::Git::VERSION = '1.006';
 use strict;
 use warnings;
 
@@ -85,23 +85,24 @@ sub test_requires_git {
     # get the git version
     my ($version) = do {
         no warnings 'uninitialized';
-        __PACKAGE__->_git_version() =~ /^git version (.*)/g;
+        __PACKAGE__->_git_version();    # tests may override this
     };
 
     # perform the check
     my ( $ok, $why ) = ( 1, '' );
-    if ($version) {
+    if ( defined $version && Git::Version::Compare::looks_like_git($version) ) {
         while ( my ( $spec, $arg ) = splice @spec, 0, 2 ) {
             if ( !$check{$spec}->( $version, $arg ) ) {
-                $ok  = 0;
+                $ok = 0;
+                $version =~ s/^git version|[\012\015]+$//g;
                 $why = "$version $spec $arg";
                 last;
             }
         }
     }
     else {
-        $ok   = 0;
-        $why  = "`$GIT` binary not available or broken";
+        $ok  = 0;
+        $why = "`$GIT` binary not available or broken";
     }
 
     # skip if needed
@@ -162,24 +163,35 @@ Test::Requires::Git - Check your test requirements against the available version
 =head1 DESCRIPTION
 
 Test::Requires::Git checks if the version of Git available for testing
-meets the given requirements.
+meets the given requirements. If the checks fail, then all tests will
+be I<skipped>.
 
-The "current git" is obtained by running C<git --version> (so the first
-C<git> binary found in the C<PATH> will be tested).
+C<use Test::Requires::Git> always calls C<test_requires_git> with the
+given arguments. If you don't want C<test_requires_git> to be called
+at import time, write this instead:
 
-If the checks fail, then all tests will be I<skipped>.
+    use Test::Requires::Git -nocheck;
+
+Passing the C<git> parameter (see L</test_requires_git> below) to
+C<use Test::Requires::Git> will override it for the rest of the program run.
 
 =head1 EXPORTED FUNCTIONS
 
 =head2 test_requires_git
 
-    # skip all
+    # skip all unless git is available as required
     test_requires_git version_ge => '1.6.5';
 
-    # giving no operator implies version_ge
+    # giving no operator implies 'version_ge'
     test_requires_git '1.6.5';
 
-    # skip 2
+    # skip 2 if git is not available
+  SKIP: {
+        test_requires_git skip => 2;
+        ...;
+    }
+
+    # skip 2 unless git is available as required
   SKIP: {
         test_requires_git
           skip       => 2,
@@ -187,15 +199,9 @@ If the checks fail, then all tests will be I<skipped>.
         ...;
     }
 
-    # skip all if git is not available
+    # skip all remaining tests if git is not available
     test_requires_git;
 
-    # skip 2 if git is not available
-  SKIP: {
-        test_requires_git skip => 2;
-        ...;
-    }
-
     # force which git binary to use
     test_requires_git
       git        => '/usr/local/bin/git',
@@ -208,21 +214,24 @@ All conditions must be satisfied for the check to pass.
 When the C<skip> parameter is given, only the specified number of tests
 will be skipped.
 
+The "current git" is obtained by running C<git --version>.
+I.e. the first C<git> binary found in the current environment will
+be tested. This is of course sensitive to local changes to C<PATH>,
+so this will behave as expected:
+
+    # skip 4 tests if there's no git available in the alternative PATH
+  SKIP: {
+        local $ENV{PATH} = $alternative_PATH;
+        test_requires_git skip => 4;
+        ...;
+    }
+
 When the C<git> parameter is given, C<test_requires_git> will run that
-instead of C<git> to perform the checks.
+program instead of C<git>.
 
 If no condition is given, C<test_requires_git> will simply check if C<git>
 is available.
 
-C<use Test::Requires::Git> always calls C<test_requires_git> with the
-given arguments. If you don't want C<test_requires_git> to be called
-at import time, write this instead:
-
-    use Test::Requires::Git -nocheck;
-
-Passing the C<git> parameter to C<use Test::Requires::Git> will override
-it for the rest of the program run.
-
 =head1 GIT VERSION CHECKING
 
 The actual comparison is handled by L<Git::Version::Compare>, so the
